.. _sec-examples:

Examples
========

.. toctree::

    ../examples/tokenisation.ipynb
    ../examples/unk-words.ipynb
    ../examples/parser.ipynb
    ../examples/reader.ipynb
    ../examples/tree-reader.ipynb
    ../examples/rewrite.ipynb
    ../examples/circuit.ipynb
    ../examples/tensor.ipynb
    ../examples/rotosolve-optimizer.ipynb
    ../examples/classical-pipeline.ipynb
    ../examples/quantum-pipeline.ipynb
    ../examples/quantum-pipeline-jax.ipynb
    ../examples/pennylane.ipynb

